netapp_ontap.models.instance_counter_aggregation API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.instance_counter_aggregation`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class InstanceCounterAggregationSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the InstanceCounterAggregation object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `complete: bool GET`

    The aggregation state for this row. For non-aggregated tables: Not present For aggregated tables: If all requests to remote nodes for counter data are successful, then this value will be 'true'. If any requests to remote nodes fail, then this value will be 'false'.

  `count: Size GET`

    Number of nodes included in the aggregation of this counter.